@@ -7,7 +7,7 @@ Main Wammu window
 __author__ = 'Michal Čihař'
 __email__ = 'michal@cihar.com'
 __license__ = '''
-Copyright (c) 2003 - 2007 Michal Čihař
+Copyright © 2003 - 2008 Michal Čihař
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of the GNU General Public License version 2 as published by
@@ -223,6 +223,10 @@ class WammuFrame(wx.Frame):
 
         wx.EVT_TREE_SEL_CHANGED(self, self.tree.GetId(), self.OnTreeSel)
 
+        # common border sizes (Gnome HIG)
+        self.separatorHalf = 3
+        self.separatorNormal = 6
+        self.separatorTwice = 12
 
         # right frame
         self.rightsplitter = wx.SplitterWindow(self.splitter, -1)
@@ -231,7 +235,7 @@ class WammuFrame(wx.Frame):
 
         # title text
         self.righttitle = wx.StaticText(self.rightwin, -1, 'Wammu')
-        self.rightwin.sizer.Add(self.righttitle, 0, wx.LEFT|wx.ALL|wx.EXPAND)
+        self.rightwin.sizer.Add(self.righttitle, 0, wx.LEFT|wx.ALL|wx.EXPAND, self.separatorNormal)
 
         # line
         self.rightwin.sizer.Add(wx.StaticLine(self.rightwin, -1), 0 , wx.EXPAND)
@@ -239,18 +243,18 @@ class WammuFrame(wx.Frame):
         # search input
         self.searchpanel = wx.Panel(self.rightwin, -1)
         self.searchpanel.sizer = wx.BoxSizer(wx.HORIZONTAL)
-        self.searchpanel.sizer.Add(wx.StaticText(self.searchpanel, -1, _('Search:')), 0, wx.LEFT | wx.CENTER)
+        self.searchpanel.sizer.Add(wx.StaticText(self.searchpanel, -1, _('Search: ')), 0, wx.LEFT | wx.CENTER)
         self.searchinput = wx.TextCtrl(self.searchpanel, -1)
         self.searchinput.SetToolTipString(_('Enter text to search for, please note that search type is selected next to this field. Matching is done over all fields.'))
         self.searchpanel.sizer.Add(self.searchinput, 1, wx.CENTER | wx.ALIGN_CENTER_VERTICAL)
         self.searchchoice = wx.Choice(self.searchpanel, choices = [_('Text'), _('Regexp'), _('Wildcard')])
         self.searchchoice.SetToolTipString(_('Select search type'))
         self.searchchoice.SetSelection(self.cfg.ReadInt('/Defaults/SearchType'))
-        self.searchpanel.sizer.Add(self.searchchoice, 0, wx.LEFT | wx.CENTER | wx.EXPAND)
+        self.searchpanel.sizer.Add(self.searchchoice, 0, wx.LEFT | wx.CENTER | wx.EXPAND, self.separatorNormal)
         self.searchclear = wx.Button(self.searchpanel, wx.ID_CLEAR)
-        self.searchpanel.sizer.Add(self.searchclear, 0, wx.LEFT | wx.CENTER | wx.EXPAND)
+        self.searchpanel.sizer.Add(self.searchclear, 0, wx.LEFT | wx.CENTER | wx.EXPAND, self.separatorNormal)
         self.searchpanel.SetSizer(self.searchpanel.sizer)
-        self.rightwin.sizer.Add(self.searchpanel, 0, wx.LEFT | wx.ALL | wx.EXPAND)
+        self.rightwin.sizer.Add(self.searchpanel, 0, wx.LEFT | wx.ALL | wx.EXPAND, self.separatorNormal)
 
         self.Bind(wx.EVT_CHOICE, self.OnSearch, self.searchchoice)
         self.Bind(wx.EVT_TEXT, self.OnSearch, self.searchinput)
@@ -471,7 +475,7 @@ class WammuFrame(wx.Frame):
                 wx.YES_NO | wx.YES_DEFAULT | wx.ICON_WARNING)
             if dlg.ShowModal() == wx.ID_YES:
                 self.SearchPhone()
-        else:
+        elif not self.cfg.HasEntry('/Gammu/Section'):
             # behave as Gammu
             self.cfg.WriteInt('/Gammu/Section', 0)
 
@@ -539,8 +543,7 @@ class WammuFrame(wx.Frame):
         if not self.cfg.HasEntry('/Gammu/Section') and self.cfg.HasEntry('/Gammu/Connection'):
             self.MigrateConfiguration()
 
-        if not self.cfg.HasEntry('/Gammu/Section'):
-            self.InitConfiguration()
+        self.InitConfiguration()
 
         self.DoDebug(self.cfg.Read('/Debug/Show'))
 
@@ -564,13 +567,17 @@ class WammuFrame(wx.Frame):
         self.dbus_notify = None
         self.last_dbus_id = 0
         if HAVE_DBUS:
-            bus = dbus.SessionBus() #mainloop = self.appparent.MainLoop)
-            interface = 'org.freedesktop.Notifications'
-            path = '/org/freedesktop/Notifications'
-            if Wammu.Utils.DBUSServiceAvailable(bus, interface, True):
-                obj = bus.get_object(interface, path)
-                self.dbus_notify = dbus.Interface(obj, interface)
-                self.dbus_notify.connect_to_signal('ActionInvoked', self.DBUSActionCallback)
+            try:
+                bus = dbus.SessionBus() #mainloop = self.appparent.MainLoop)
+                interface = 'org.freedesktop.Notifications'
+                path = '/org/freedesktop/Notifications'
+                if Wammu.Utils.DBUSServiceAvailable(bus, interface, True):
+                    obj = bus.get_object(interface, path)
+                    self.dbus_notify = dbus.Interface(obj, interface)
+                    self.dbus_notify.connect_to_signal('ActionInvoked', self.DBUSActionCallback)
+            except dbus.DBusException:
+                self.dbus_notify = None
+                self.last_dbus_id = 0
 
     def SetupTrayIcon(self):
         if self.cfg.Read('/Wammu/TaskBarIcon') != 'yes':
@@ -652,6 +659,7 @@ class WammuFrame(wx.Frame):
                 if s['SignalPercent'] == -1:
                     signal = _('Unknown')
                 else:
+                    # l10n: Formatting of signal percentage, usually you can keep this as it is.
                     signal = _('%d %%') % s['SignalPercent']
 
                 self.SetStatusText(_('Bat: %(battery_percent)d %% (%(power_source)s), Sig: %(signal_level)s, Time: %(time)s') %
@@ -2020,6 +2028,12 @@ class WammuFrame(wx.Frame):
         wx.Yield()
         section = self.cfg.ReadInt('/Gammu/Section')
         config = self.cfg.gammu.GetConfig(section)
+        if config['Connection'] == '' or config['Device'] == '':
+            wx.MessageDialog(self,
+                _('Phone connection is not properly configured, can not connect to phone.'),
+                _('Connection not configured!'),
+                wx.OK | wx.ICON_ERROR).ShowModal()
+            return
         cfg = {
             'StartInfo': self.cfg.Read('/Gammu/StartInfo'),
             'UseGlobalDebugFile': 1,
@@ -2038,7 +2052,10 @@ class WammuFrame(wx.Frame):
         try:
             self.sm.Init()
             self.sm.SetIncomingCallback(self.IncomingEvent)
-            self.sm.SetIncomingCall(True)
+            try:
+                self.sm.SetIncomingCall(True)
+            except gammu.GSMError:
+                pass
             self.TogglePhoneMenus(True)
             self.SetupNumberPrefix()
             try:
