@@ -7,7 +7,7 @@ Settings storage and configuration manager
 __author__ = 'Michal Čihař'
 __email__ = 'michal@cihar.com'
 __license__ = '''
-Copyright (c) 2003 - 2007 Michal Čihař
+Copyright © 2003 - 2008 Michal Čihař
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of the GNU General Public License version 2 as published by
@@ -27,6 +27,7 @@ import sys
 import os
 import Wammu.Paths
 import Wammu.Data
+import Wammu.Utils
 
 COM_PORTS = 16
 UNX_DEVICES = 4
@@ -242,23 +243,15 @@ class Settings:
             return []
         except bluetooth.BluetoothError:
             return []
+        except IOError:
+            return []
 
     def CheckDev(self, dev):
-        if sys.platform == 'win32':
-            try:
-                import win32file
-                if dev[:3] == 'COM':
-                    try:
-                        win32file.QueryDosDevice(dev)
-                        return True
-                    except:
-                        pass
-            except ImportError:
-                return True
+        res = Wammu.Utils.CheckDeviceNode(dev)
+        if res[0] == 0:
+            return True
         else:
-            if dev[0] == '/' and os.path.exists(dev):
-                return True
-        return False
+            return False
 
     def AddDevs(self, lst, format, limit):
         for x in range(limit):
