@@ -7,7 +7,7 @@ Misc functions like charset conversion, entries parsers,..
 __author__ = 'Michal Čihař'
 __email__ = 'michal@cihar.com'
 __license__ = '''
-Copyright (c) 2003 - 2007 Michal Čihař
+Copyright © 2003 - 2008 Michal Čihař
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of the GNU General Public License version 2 as published by
@@ -494,6 +494,21 @@ def CheckDeviceNode(curdev):
     - error dialog title
     - error dialog text
     '''
+    if sys.platform == 'win32':
+        try:
+            import win32file
+            if curdev[:3] == 'COM':
+                try:
+                    win32file.QueryDosDevice(curdev)
+                    return (0, '', '', '')
+                except:
+                    return (-1,
+                            _('Device %s does not exist!') % curdev,
+                            _('Error opening device'),
+                            _('Device %s does not exist!') % curdev
+                            )
+        except ImportError:
+            return (0, '', '', '')
     if not os.path.exists(curdev):
         return (-1,
                 _('Device %s does not exist!') % curdev,
